# crunchflow

The Python crunchflow package is a toolbox for working with the CrunchFlow reactive transport model. It can be particularly useful for analyzing and plotting CrunchFlow model output.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install crunchflow.

```bash
pip install crunchflow
```

## Usage
Functions and classes are well documented within each individual module file. Full documentation is coming soon.

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[GPL](https://choosealicense.com/licenses/gpl-3.0/)
